@@ -408,7 +408,7 @@ void                fm_directory_view_new_file                         (FMDirect
 									NautilusFile     *source);
 void                fm_directory_view_ignore_hidden_file_preferences   (FMDirectoryView  *view);
 void                fm_directory_view_init_view_iface                  (NautilusViewIface *iface);
-void                fm_directory_view_handle_url_drop                  (FMDirectoryView  *view,
+void                fm_directory_view_handle_netscape_url_drop         (FMDirectoryView  *view,
 									const char       *encoded_url,
 									const char       *target_uri,
 									GdkDragAction     action,
